@@ -16,7 +16,7 @@ teardown() {
 }
 
 main() {
-    export KUBEVIRT_NUM_NODES=5 # 1 master, 4 workers
+    export KUBEVIRT_NUM_NODES=5 # 1 control-plane, 4 workers
     source automation/check-patch.setup.sh
     cd ${TMP_PROJECT_PATH}
 
@@ -31,9 +31,7 @@ main() {
     trap teardown EXIT SIGINT SIGTERM SIGSTOP
     make cluster-sync
 
-    export E2E_TEST_SUITE_ARGS="--junit-output=$ARTIFACTS/junit.functest.xml"
-
-    make E2E_TEST_TIMEOUT=80m E2E_TEST_ARGS="-noColor" test-e2e-handler
+    make E2E_TEST_TIMEOUT=2h E2E_TEST_ARGS="--no-color --output-dir=$ARTIFACTS --junit-report=junit.functest.xml" test-e2e-handler
 }
 
 [[ "${BASH_SOURCE[0]}" == "$0" ]] && main "$@"
