@@ -20,14 +20,11 @@ package conditions
 import (
 	"testing"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-
-	"github.com/onsi/ginkgo/reporters"
 )
 
 func TestUnit(t *testing.T) {
 	RegisterFailHandler(Fail)
-	junitReporter := reporters.NewJUnitReporter("junit.controller-nodenetworkconfigurationpolicy-enactmentstatus-conditions_suite_test.xml")
-	RunSpecsWithDefaultAndCustomReporters(t, "Enactment Status Conditions Test Suite", []Reporter{junitReporter})
+	RunSpecs(t, "Enactment Status Conditions Test Suite")
 }
