@@ -25,14 +25,19 @@ import (
 )
 
 type rootState struct {
-	Interfaces  []interfaceState `json:"interfaces" yaml:"interfaces"`
-	Routes      *routesState     `json:"routes,omitempty" yaml:"routes,omitempty"`
+	Interfaces  []interfaceState `json:"interfaces"             yaml:"interfaces"`
+	Routes      *routes          `json:"routes,omitempty"       yaml:"routes,omitempty"`
 	DNSResolver *dnsResolver     `json:"dns-resolver,omitempty" yaml:"dns-resolver,omitempty"`
 }
 
-type routesState struct {
-	Config  []interface{} `json:"config" yaml:"config"`
-	Running []interface{} `json:"running" yaml:"running"`
+type routes struct {
+	Config  []routeState `json:"config"  yaml:"config"`
+	Running []routeState `json:"running" yaml:"running"`
+}
+
+type routeState struct {
+	routeFields `yaml:",inline"`
+	Data        map[string]interface{}
 }
 
 type interfaceState struct {
@@ -55,6 +60,11 @@ type interfaceFields struct {
 	Name string `json:"name" yaml:"name"`
 }
 
+// routeFields allows unmarshaling directly into the defined fields
+type routeFields struct {
+	NextHopInterface string `json:"next-hop-interface" yaml:"next-hop-interface"`
+}
+
 func (i interfaceState) MarshalJSON() (output []byte, err error) {
 	i.Data["name"] = i.Name
 	return json.Marshal(i.Data)
@@ -73,3 +83,22 @@ func (i *interfaceState) UnmarshalJSON(b []byte) error {
 	i.interfaceFields = ifaceFields
 	return nil
 }
+
+func (r routeState) MarshalJSON() (output []byte, err error) {
+	r.Data["next-hop-interface"] = r.NextHopInterface
+	return json.Marshal(r.Data)
+}
+
+func (r *routeState) UnmarshalJSON(b []byte) error {
+	if err := yaml.Unmarshal(b, &r.Data); err != nil {
+		return fmt.Errorf("failed Unmarshaling b: %w", err)
+	}
+
+	var fields routeFields
+	if err := yaml.Unmarshal(b, &fields); err != nil {
+		return fmt.Errorf("failed Unmarchaling raw: %w", err)
+	}
+	r.Data["next-hop-interface"] = fields.NextHopInterface
+	r.routeFields = fields
+	return nil
+}
