@@ -24,20 +24,19 @@ import (
 	"testing"
 	"time"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
+	"github.com/onsi/ginkgo/v2/types"
 	. "github.com/onsi/gomega"
 
-	ginkgoreporters "kubevirt.io/qe-tools/pkg/ginkgo-reporters"
-
 	corev1 "k8s.io/api/core/v1"
 
-	knmstatereporter "github.com/nmstate/kubernetes-nmstate/test/reporter"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/log/zap"
 
 	testenv "github.com/nmstate/kubernetes-nmstate/test/env"
 	"github.com/nmstate/kubernetes-nmstate/test/environment"
+	knmstatereporter "github.com/nmstate/kubernetes-nmstate/test/reporter"
 )
 
 var (
@@ -54,6 +53,7 @@ var (
 	miimonFormat         string
 	nodesInterfacesState = make(map[string][]byte)
 	interfacesToIgnore   = []string{"flannel.1", "dummy0"}
+	knmstateReporter     *knmstatereporter.KubernetesNMStateReporter
 )
 
 var _ = BeforeSuite(func() {
@@ -94,6 +94,9 @@ var _ = BeforeSuite(func() {
 	}
 
 	resetDesiredStateForNodes()
+
+	knmstateReporter = knmstatereporter.New("test_logs/e2e/handler", testenv.OperatorNamespace, nodes)
+	knmstateReporter.Cleanup()
 })
 
 func TestE2E(t *testing.T) {
@@ -101,16 +104,7 @@ func TestE2E(t *testing.T) {
 
 	RegisterFailHandler(Fail)
 
-	reporters := make([]Reporter, 0)
-	reporters = append(reporters, knmstatereporter.New("test_logs/e2e/handler", testenv.OperatorNamespace, nodes))
-	if ginkgoreporters.Polarion.Run {
-		reporters = append(reporters, &ginkgoreporters.Polarion)
-	}
-	if ginkgoreporters.JunitOutput != "" {
-		reporters = append(reporters, ginkgoreporters.NewJunitReporter())
-	}
-
-	RunSpecsWithDefaultAndCustomReporters(t, "E2E Test Suite", reporters)
+	RunSpecs(t, "Handler E2E Test Suite")
 }
 
 var _ = BeforeEach(func() {
@@ -139,6 +133,14 @@ var _ = AfterEach(func() {
 	}
 })
 
+var _ = ReportBeforeEach(func(specReport types.SpecReport) {
+	knmstateReporter.ReportBeforeEach(specReport)
+})
+
+var _ = ReportAfterEach(func(specReport types.SpecReport) {
+	knmstateReporter.ReportAfterEach(specReport)
+})
+
 func containsNode(nodes []string, node string) bool {
 	for _, n := range nodes {
 		if n == node {
