@@ -1,9 +1,24 @@
+/*
+Copyright The Kubernetes NMState Authors.
+
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
+
 package handler
 
 import (
-	"fmt"
-
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	nmstate "github.com/nmstate/kubernetes-nmstate/api/shared"
@@ -24,7 +39,7 @@ var _ = Describe("Enactment DesiredState", func() {
 		It("should have desiredState for node", func() {
 			for _, node := range nodes {
 				enactmentKey := nmstate.EnactmentKey(node, TestPolicy)
-				By(fmt.Sprintf("Check enactment %s has expected desired state", enactmentKey.Name))
+				Byf("Check enactment %s has expected desired state", enactmentKey.Name)
 				nnce := nodeNetworkConfigurationEnactment(enactmentKey)
 				Expect(nnce.Status.DesiredState).To(MatchYAML(linuxBrUpWithDefaults(bridge1)))
 			}
