@@ -1,10 +1,27 @@
+/*
+Copyright The Kubernetes NMState Authors.
+
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
+
 package handler
 
 import (
 	"fmt"
 	"time"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	"k8s.io/apimachinery/pkg/types"
@@ -13,6 +30,8 @@ import (
 	nmstatenode "github.com/nmstate/kubernetes-nmstate/pkg/node"
 )
 
+const expectedDummyName = "dummy0"
+
 var _ = Describe("[nns] NNS LastSuccessfulUpdateTime", func() {
 	var (
 		originalNNSs map[string]nmstatev1beta1.NodeNetworkState
@@ -35,7 +54,7 @@ var _ = Describe("[nns] NNS LastSuccessfulUpdateTime", func() {
 					currentStatus := nodeNetworkState(key).Status
 					originalStatus := originalNNS.Status
 					if currentStatus.CurrentState.String() == originalStatus.CurrentState.String() {
-						By(fmt.Sprintf("Check LastSuccessfulUpdateTime changed at %s", node))
+						Byf("Check LastSuccessfulUpdateTime changed at %s", node)
 						Expect(currentStatus.LastSuccessfulUpdateTime).To(Equal(originalStatus.LastSuccessfulUpdateTime))
 					} else {
 						return fmt.Errorf("Network configuration changed, sending and error to retry")
@@ -46,8 +65,6 @@ var _ = Describe("[nns] NNS LastSuccessfulUpdateTime", func() {
 		})
 	})
 	Context("when network configuration is changed externally", func() {
-		expectedDummyName := "dummy0"
-
 		BeforeEach(func() {
 			createDummyConnectionAtAllNodes(expectedDummyName)
 		})
@@ -56,7 +73,7 @@ var _ = Describe("[nns] NNS LastSuccessfulUpdateTime", func() {
 		})
 		It("should update it with according to network state refresh duration", func() {
 			for node, originalNNS := range originalNNSs {
-				By(fmt.Sprintf("Checking timestamp against original one %s", originalNNS.Status.LastSuccessfulUpdateTime))
+				Byf("Checking timestamp against original one %s", originalNNS.Status.LastSuccessfulUpdateTime)
 				Eventually(func() time.Time {
 					currentNNS := nodeNetworkState(types.NamespacedName{Name: node})
 					return currentNNS.Status.LastSuccessfulUpdateTime.Time
@@ -67,15 +84,13 @@ var _ = Describe("[nns] NNS LastSuccessfulUpdateTime", func() {
 	})
 	Context("when network configuration is changed by a NNCP", func() {
 		BeforeEach(func() {
-			// We want to test all the NNS so we apply policies to masters and workers
-			setDesiredStateWithPolicyWithoutNodeSelector(TestPolicy, linuxBrUp(bridge1))
+			// We want to test all the NNS so we apply policies to control-plane and workers (use linuxBrUpNoPorts to not affect the nodes secondary interfaces state)
+			setDesiredStateWithPolicyWithoutNodeSelector(TestPolicy, linuxBrUpNoPorts(bridge1))
 			waitForAvailableTestPolicy()
 		})
 		AfterEach(func() {
 			setDesiredStateWithPolicyWithoutNodeSelector(TestPolicy, linuxBrAbsent(bridge1))
 			waitForAvailableTestPolicy()
-			setDesiredStateWithPolicyWithoutNodeSelector(TestPolicy, resetPrimaryAndSecondaryNICs())
-			waitForAvailableTestPolicy()
 			deletePolicy(TestPolicy)
 		})
 		It("should be immediately updated", func() {
