@@ -1,11 +1,27 @@
+/*
+Copyright The Kubernetes NMState Authors.
+
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
+
 package handler
 
 import (
 	"context"
-	"fmt"
 	"time"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	corev1 "k8s.io/api/core/v1"
@@ -17,7 +33,7 @@ import (
 	"github.com/nmstate/kubernetes-nmstate/pkg/enactment"
 )
 
-var _ = Describe("[rfe_id:3503][crit:medium][vendor:cnv-qe@redhat.com][level:component]NodeSelector", func() {
+var _ = Describe("NodeSelector", func() {
 	var (
 		testNodeSelector            = map[string]string{"testKey": "testValue"}
 		numberOfEnactmentsForPolicy = func(policyName string) int {
@@ -29,25 +45,20 @@ var _ = Describe("[rfe_id:3503][crit:medium][vendor:cnv-qe@redhat.com][level:com
 	)
 	Context("when policy is set with node selector not matching any nodes", func() {
 		BeforeEach(func() {
-			By(fmt.Sprintf("Set policy %s with not matching node selector", bridge1))
-			setDesiredStateWithPolicyAndNodeSelectorEventually(bridge1, linuxBrUp(bridge1), testNodeSelector)
+			Byf("Set policy %s with not matching node selector", bridge1)
+			// use linuxBrUpNoPorts to not affect the nodes secondary interfaces state
+			setDesiredStateWithPolicyAndNodeSelectorEventually(bridge1, linuxBrUpNoPorts(bridge1), testNodeSelector)
 			waitForAvailablePolicy(bridge1)
 		})
 
 		AfterEach(func() {
-			By(fmt.Sprintf("Deleteting linux bridge %s at all nodes", bridge1))
+			Byf("Deleteting linux bridge %s at all nodes", bridge1)
 			setDesiredStateWithPolicyWithoutNodeSelector(bridge1, linuxBrAbsent(bridge1))
 			waitForAvailablePolicy(bridge1)
 			deletePolicy(bridge1)
-			setDesiredStateWithPolicyWithoutNodeSelector(TestPolicy, resetPrimaryAndSecondaryNICs())
-			waitForAvailableTestPolicy()
-			deletePolicy(TestPolicy)
-
-			By("Remove test label from node")
-			removeLabelsFromNode(nodes[0], testNodeSelector)
 		})
 
-		It("[test_id:3813]should not update any nodes and have not enactments", func() {
+		It("should not update any nodes and have not enactments", func() {
 			for _, node := range allNodes {
 				interfacesNameForNodeEventually(node).ShouldNot(ContainElement(bridge1))
 			}
@@ -56,8 +67,9 @@ var _ = Describe("[rfe_id:3503][crit:medium][vendor:cnv-qe@redhat.com][level:com
 
 		Context("and we remove the node selector", func() {
 			BeforeEach(func() {
-				By(fmt.Sprintf("Remove node selector at policy %s", bridge1))
-				setDesiredStateWithPolicyWithoutNodeSelector(bridge1, linuxBrUp(bridge1))
+				Byf("Remove node selector at policy %s", bridge1)
+				// use linuxBrUpNoPorts to not affect the nodes secondary interfaces state
+				setDesiredStateWithPolicyWithoutNodeSelector(bridge1, linuxBrUpNoPorts(bridge1))
 				waitForAvailablePolicy(bridge1)
 			})
 
@@ -78,6 +90,10 @@ var _ = Describe("[rfe_id:3503][crit:medium][vendor:cnv-qe@redhat.com][level:com
 				time.Sleep(3 * time.Second)
 				waitForAvailablePolicy(bridge1)
 			})
+			AfterEach(func() {
+				By("Remove test label from node")
+				removeLabelsFromNode(nodes[0], testNodeSelector)
+			})
 			It("should apply the policy", func() {
 				By("Check that NNCE is created")
 				nodeNetworkConfigurationEnactment(shared.EnactmentKey(nodes[0], bridge1))
@@ -123,7 +139,7 @@ func removeLabelsFromNode(nodeName string, labelsToRemove map[string]string) {
 		return
 	}
 
-	for k, _ := range labelsToRemove {
+	for k := range labelsToRemove {
 		delete(node.Labels, k)
 	}
 
