@@ -22,13 +22,15 @@ import (
 	"fmt"
 	"time"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
+	"k8s.io/client-go/util/retry"
+	"sigs.k8s.io/controller-runtime/pkg/client"
 
 	"github.com/nmstate/kubernetes-nmstate/test/cmd"
 	"github.com/nmstate/kubernetes-nmstate/test/e2e/daemonset"
@@ -37,14 +39,37 @@ import (
 )
 
 var _ = Describe("NMState operator", func() {
+	type controlPlaneTest struct {
+		withMultiNode bool
+	}
+	DescribeTable("for control-plane size",
+		func(tc controlPlaneTest) {
+			if isKubevirtciCluster() && tc.withMultiNode {
+				kubevirtciReset := increaseKubevirtciControlPlane()
+				defer kubevirtciReset()
+			}
+			if tc.withMultiNode && len(controlPlaneNodes()) < 2 {
+				Skip("cluster control-plane size should be > 1")
+			}
+			if !tc.withMultiNode && len(controlPlaneNodes()) > 1 {
+				Skip("cluster control-plane size should be < 2")
+			}
+
+			installNMState(defaultOperator.nmstate)
+			defer uninstallNMStateAndWaitForDeletion(defaultOperator)
+			eventuallyOperandIsReady(defaultOperator)
+
+			By("Check webhook is distributed across control-plane nodes")
+			podsShouldBeDistributedAtNodes(controlPlaneNodes(), client.MatchingLabels{"component": "kubernetes-nmstate-webhook"})
+		},
+		Entry("of a single node shoud deploy webhook replicas at the same node", controlPlaneTest{withMultiNode: false}),
+		Entry("of two nodes should deploy webhook replicas at different nodes", controlPlaneTest{withMultiNode: true}),
+	)
 	Context("when installed for the first time", func() {
 		BeforeEach(func() {
 			By("Install NMState for the first time")
 			installNMState(defaultOperator.nmstate)
 		})
-		It("should deploy a ready operand", func() {
-			eventuallyOperandIsReady(defaultOperator)
-		})
 		AfterEach(func() {
 			uninstallNMStateAndWaitForDeletion(defaultOperator)
 		})
@@ -133,3 +158,32 @@ func uninstallOperator(operator operatorTestData) {
 	Expect(testenv.Client.Delete(context.TODO(), &ns)).To(SatisfyAny(Succeed(), WithTransform(apierrors.IsNotFound, BeTrue())))
 	eventuallyIsNotFound(types.NamespacedName{Name: operator.ns}, &ns, "should delete the namespace")
 }
+
+func increaseKubevirtciControlPlane() func() {
+	secondNodeName := "node02"
+	node := &corev1.Node{}
+	err := retry.RetryOnConflict(retry.DefaultRetry, func() error {
+		err := testenv.Client.Get(context.TODO(), client.ObjectKey{Name: secondNodeName}, node)
+		if err != nil {
+			return err
+		}
+		By(fmt.Sprintf("Configure kubevirtci cluster node %s as control plane", node.Name))
+		node.Labels["node-role.kubernetes.io/control-plane"] = ""
+		node.Labels["node-role.kubernetes.io/master"] = ""
+		return testenv.Client.Update(context.TODO(), node)
+	})
+	Expect(err).ToNot(HaveOccurred())
+	return func() {
+		err := retry.RetryOnConflict(retry.DefaultRetry, func() error {
+			err := testenv.Client.Get(context.TODO(), client.ObjectKey{Name: secondNodeName}, node)
+			if err != nil {
+				return err
+			}
+			By(fmt.Sprintf("Configure kubevirtci cluster node %s as non control plane", node.Name))
+			delete(node.Labels, "node-role.kubernetes.io/control-plane")
+			delete(node.Labels, "node-role.kubernetes.io/master")
+			return testenv.Client.Update(context.TODO(), node)
+		})
+		Expect(err).ToNot(HaveOccurred())
+	}
+}
